==> node-espree_7.3.1~dfsg1.orig.tar.xz: espree-7.3.1/tests/fixtures/ecma-version/9/regexp-named-group/valid-unicode-name-1.result.js <==
const conditionalRegex = require("../../../../lib/conditional-regex-value");

module.exports = {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 1,
            "column": 20
        }
    },
    "range": [
        0,
        20
    ],
    "body": [
        {
            "type": "ExpressionStatement",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 20
                }
            },
            "range": [
                0,
                20
            ],
            "expression": conditionalRegex({
                "type": "Literal",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 0
                    },
                    "end": {
                        "line": 1,
                        "column": 20
                    }
                },
                "range": [
                    0,
                    20
                ],
                "value": null,
                "raw": "/(?<\\u0041\\u0042>a)/",
                "regex": {
                    "pattern": "(?<\\u0041\\u0042>a)",
                    "flags": ""
                }
            })
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "RegularExpression",
            "value": "/(?<\\u0041\\u0042>a)/",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 20
                }
            },
            "range": [
                0,
                20
            ],
            "regex": {
                "flags": "",
                "pattern": "(?<\\u0041\\u0042>a)"
            }
        }
    ]
};

==> node-espree_9.4.1~dfsg.orig.tar.xz: espree-9.4.1/tests/fixtures/ecma-version/9/regexp-named-group/valid-unicode-name-1.result.js <==
import conditionalRegex from "../../../../lib/conditional-regex-value.js";

export default {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 1,
            "column": 20
        }
    },
    "range": [
        0,
        20
    ],
    "body": [
        {
            "type": "ExpressionStatement",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 20
                }
            },
            "range": [
                0,
                20
            ],
            "expression": conditionalRegex({
                "type": "Literal",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 0
                    },
                    "end": {
                        "line": 1,
                        "column": 20
                    }
                },
                "range": [
                    0,
                    20
                ],
                "value": null,
                "raw": "/(?<\\u0041\\u0042>a)/",
                "regex": {
                    "pattern": "(?<\\u0041\\u0042>a)",
                    "flags": ""
                }
            })
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "RegularExpression",
            "value": "/(?<\\u0041\\u0042>a)/",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 20
                }
            },
            "range": [
                0,
                20
            ],
            "regex": {
                "flags": "",
                "pattern": "(?<\\u0041\\u0042>a)"
            }
        }
    ]
};
